@@ -57,7 +57,7 @@ def run_many_consumer_with_multi_process(consumer_init_params_list: List[dict],
 def task_deco(queue_name, *, function_timeout=0,
               concurrent_num=50, specify_concurrent_pool=None, specify_async_loop=None, concurrent_mode=1,
               max_retry_times=3, log_level=10, is_print_detail_exception=True, msg_schedule_time_intercal=0.0,
-              qps: float = 0, msg_expire_senconds=0, is_using_distributed_frequency_control=False,
+              qps: float = 0, is_using_distributed_frequency_control=False, msg_expire_senconds=0,
               is_send_consumer_hearbeat_to_redis=False,
               logger_prefix='', create_logger_file=True, do_task_filtering=False, task_filtering_expire_seconds=0,
               is_consuming_function_use_multi_params=True,
